@@ -1,7 +1,10 @@
 from botocore import monitoring as botomonitoring
 from . import monitor
+from .logging import configure_root_logger
+from .config import CONFIG
 from botocore.session import Session as BaseSession
-import os
+
+logger = configure_root_logger(__name__)
 
 
 class Session(BaseSession):
@@ -15,17 +18,29 @@ class Session(BaseSession):
         )
 
     def _create_iamzero_monitor(self):
-        # TODO: call AWS STS get-caller-identity endpoint in background to determine identity
-        arn = "arn:aws:sts::123456789:assumed-role/AWSReservedSSO_AWSReadOnlyAccess_90da1eee638a66fc/chris@exponentlabs.io"
-        user_id = "DSAFLKJHCAYBUAE:chris@exponentlabs.io"
-        account = "123456789"
+        # TODO: recreating an entire botocore Session here is likely hugely inefficient.
+        # Is this executing in the main Python thread?
+        # Need to profile impact on performance and then consider optimising this to
+        # run in a background thread.
+        logger.debug("Creating monitor")
+        session = BaseSession()
+        sts = session.create_client("sts")
+        identity = sts.get_caller_identity()
 
-        iamzero_host = os.getenv("IAMZERO_HOST", "https://app.iamzero.dev")
+        arn = identity["Arn"]
+        user_id = identity["UserId"]
+        account = identity["Account"]
+
+        logger.debug(f"Registered caller identity: {arn}")
+
+        iamzero_url = CONFIG["URL"]
+        token = CONFIG["TOKEN"]
 
         handler = botomonitoring.Monitor(
             adapter=monitor.IAMZMonitorEventAdapter(),
             publisher=monitor.IAMZPublisher(
-                host=iamzero_host,
+                url=iamzero_url,
+                token=token,
                 serializer=monitor.IAMZSerializer(
                     arn=arn, user_id=user_id, account=account
                 ),
@@ -69,4 +84,4 @@ def get_session(env_vars=None):
     """
     Return a new session object.
     """
-    return Session(env_vars)
\ No newline at end of file
+    return Session(env_vars)
